#!/usr/bin/env python3

"""
Get the `k`-th left or right digit from a number.
"""

def get_len(n):
    """
    Returns the length of a natural number `n`.
    """
    res = 0
    while n > 0:
        res += 1
        n //= 10
    return res

def get_digit(n, *, left=None, right=None):
    """
    Returns either the `left`-th digit of `n` from the left or
    the `right`-th digit of `n` from the right (but not both!).
    """
    n = abs(n)
    # Neither left nor right were given
    if left is None and right is None:
        return -1
    # Left was given
    if left is not None:
        # Both were given
        if right is not None:
            return -1
        # The digit doesn't exist
        if left > get_len(n):
            return -1
        # Get the `left`-th digit from the left
        for _ in range(get_len(n) - left):
            n //= 10
        return n % 10
    # Only right is given
    for _ in range(right - 1):
        n //= 10
    return n % 10


def main():
    """
    A function testing get_digit() for different input cases.
    """
    n = 123456
    k = 3
    print(str(k) + ". digit from the left:  ", get_digit(n, left=k))
    print(str(k) + ". digit from the right: ", get_digit(n, right=k))
    print(str(k) + ". digit from both sides:", get_digit(n, left=k, right=k))
    print(str(k) + ". digit from no sides:  ", get_digit(n))
    
main()
